/*
 * IdentityWindow.cpp
 * Copyright (C) 2024 pulkomandy <pulkomandy@kitt>
 *
 * Distributed under terms of the MIT license.
 */

#include "IdentityWindow.h"

#include <Application.h>
#include <Button.h>
#include <GridView.h>
#include <GroupLayout.h>
#include <LayoutBuilder.h>
#include <RadioButton.h>
#include <StringView.h>

extern bool gGender;
extern BString gFirstName;
extern BString gLastName;

IdentityWindow::IdentityWindow()
	: BWindow(BRect(0, 0, 100, 100), "Who are you?", B_TITLED_WINDOW, B_NOT_RESIZABLE | B_AUTO_UPDATE_SIZE_LIMITS)
{
	BGridView* gv = new BGridView();

	BMessage* male = new BMessage('GEND');
	male->AddBool("gender", 0);

	BMessage* female = new BMessage('GEND');
	female->AddBool("gender", 1);

	BTextControl* firstName = new BTextControl("first name", "First name", "", NULL);
	BTextControl* lastName = new BTextControl("last name", "Last name", "", NULL);

	firstName->SetModificationMessage(new BMessage('FRST'));
	lastName->SetModificationMessage(new BMessage('LAST'));

	BLayoutBuilder::Grid<>(gv, B_VERTICAL)
		.SetInsets(B_USE_WINDOW_SPACING)
		.AddTextControl(firstName, 0, 0, B_ALIGN_HORIZONTAL_UNSET, 1, 2)
		.AddTextControl(lastName, 0, 1, B_ALIGN_HORIZONTAL_UNSET, 1, 2)
		.Add(new BStringView("gender", "Gender"), 0, 2)
		.Add(new BRadioButton("male", "Male", male), 1, 2)
		.Add(new BRadioButton("female", "Female", female), 2, 2)
		.Add(new BButton("ok", "Ok", new BMessage(B_QUIT_REQUESTED)), 1, 3)
	.End();

	SetLayout(new BGroupLayout(B_VERTICAL));
	AddChild(gv);
}

bool IdentityWindow::QuitRequested()
{
	be_app->PostMessage('STRT');

	return BWindow::QuitRequested();
}

void IdentityWindow::MessageReceived(BMessage* message)
{
	switch (message->what)
	{
		case 'GEND':
			gGender = message->FindBool("gender");
			return;
		case 'FRST':
		{
			BTextControl* tc;
			message->FindPointer("source", (void**)&tc);
			gFirstName = tc->Text();
			return;
		}
		case 'LAST':
		{
			BTextControl* tc;
			message->FindPointer("source", (void**)&tc);
			gLastName = tc->Text();
			return;
		}
	}
	BWindow::MessageReceived(message);
}
